@@ -1,6 +1,6 @@
 #!/bin/sh
 # gen-doc.sh
-#        Copyright (C) 2002 Timo Schulz
+#        Copyright (C) 2002, 2007 Timo Schulz
 #
 # This file is part of OpenCDK.
 #
@@ -13,12 +13,12 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with OpenCDK; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 rm -f opencdk-api.html
+echo "<html>" >> opencdk-api.html
+echo "<title>OpenCDK API Overview</title><body>" >> opencdk-api.html
+echo "<head></head>" >> opencdk-api.html
+cat intro.html >> opencdk-api.html
 cd ..
 cd src
 for i in `ls *.c`; do
@@ -26,3 +26,4 @@ for i in `ls *.c`; do
     ../doc/gdoc -html $i >> ../doc/opencdk-api.html
     echo "ok"
 done
+echo "</body></html>" >> opencdk-api.html
